==> 0.0.6.tar.gz: android/src/main/java/com/ininwork/onechuan_plugin/OnechuanPlugin.java <==
package com.ininwork.onechuan_plugin;

import android.content.Context;
import android.database.Cursor;
import android.provider.ContactsContract;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** OnechuanPlugin */
public class OnechuanPlugin implements MethodCallHandler {
    Registrar registrar;
    public OnechuanPlugin(Registrar registrar) {
        this.registrar = registrar;
    }

    /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "onechuan_plugin");
    channel.setMethodCallHandler(new OnechuanPlugin(registrar));
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if(call.method.equals("getContacts")){
        ArrayList<Map<String,Object>> contacts = getAllContacts(registrar.context());
        result.success(contacts);
    }
    else {
      result.notImplemented();
    }
  }
    public static ArrayList<Map<String,Object>> getAllContacts(Context context) {
        ArrayList<Map<String,Object>> contacts = new ArrayList<Map<String,Object>>();
        Cursor cursor = context.getContentResolver().query(
                ContactsContract.Contacts.CONTENT_URI, null, null, null, null);
        while (cursor.moveToNext()) {
            //新建一个联系人实例
//            MyContacts temp = new MyContacts();
            Map<String,Object> map = new HashMap<>();
            String contactId = cursor.getString(cursor
                    .getColumnIndex(ContactsContract.Contacts._ID));
            //获取联系人姓名
            String name = cursor.getString(cursor
                    .getColumnIndex(ContactsContract.Contacts.DISPLAY_NAME));
            map.put("name",name);
//            temp.name = name;

            //获取联系人电话号码
            Cursor phoneCursor = context.getContentResolver().query(ContactsContract.CommonDataKinds.Phone.CONTENT_URI,
                    null, ContactsContract.CommonDataKinds.Phone.CONTACT_ID + "=" + contactId, null, null);
            while (phoneCursor.moveToNext()) {
                String phone = phoneCursor.getString(phoneCursor.getColumnIndex(ContactsContract.CommonDataKinds.Phone.NUMBER));
                phone = phone.replace("-", "");
                phone = phone.replace(" ", "");
                map.put("phone",phone);
            }

            contacts.add(map);
            //记得要把cursor给close掉
            phoneCursor.close();
        }
        cursor.close();
        return contacts;
    }


}

==> 0.0.8.tar.gz: android/src/main/java/com/ininwork/onechuan_plugin/OnechuanPlugin.java <==
package com.ininwork.onechuan_plugin;

import android.content.Context;
import android.database.Cursor;
import android.provider.ContactsContract;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** OnechuanPlugin */
public class OnechuanPlugin implements MethodCallHandler {
    Registrar registrar;
    public OnechuanPlugin(Registrar registrar) {
        this.registrar = registrar;
    }

    /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "onechuan_plugin");
    channel.setMethodCallHandler(new OnechuanPlugin(registrar));
  }

  @Override
  public void onMethodCall(MethodCall call, final Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if(call.method.equals("getContacts")){
        new Thread(new Runnable() {
            @Override
            public void run() {
                final ArrayList<Map<String,Object>> contacts = getAllContacts(registrar.context());
                registrar.activity().runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        result.success(contacts);
                    }
                });
            }
        }).start();
    }
    else {
      result.notImplemented();
    }
  }
    public static ArrayList<Map<String,Object>> getAllContacts(Context context) {
        ArrayList<Map<String,Object>> contacts = new ArrayList<Map<String,Object>>();
        Cursor cursor = context.getContentResolver().query(
                ContactsContract.Contacts.CONTENT_URI, null, null, null, null);
        while (cursor.moveToNext()) {
            //新建一个联系人实例
//            MyContacts temp = new MyContacts();
            Map<String,Object> map = new HashMap<>();
            String contactId = cursor.getString(cursor
                    .getColumnIndex(ContactsContract.Contacts._ID));
            //获取联系人姓名
            String name = cursor.getString(cursor
                    .getColumnIndex(ContactsContract.Contacts.DISPLAY_NAME));
            map.put("name",name);
//            temp.name = name;

            //获取联系人电话号码
            Cursor phoneCursor = context.getContentResolver().query(ContactsContract.CommonDataKinds.Phone.CONTENT_URI,
                    null, ContactsContract.CommonDataKinds.Phone.CONTACT_ID + "=" + contactId, null, null);
            while (phoneCursor.moveToNext()) {
                String phone = phoneCursor.getString(phoneCursor.getColumnIndex(ContactsContract.CommonDataKinds.Phone.NUMBER));
                phone = phone.replace("-", "");
                phone = phone.replace(" ", "");
                map.put("phone",phone);
            }

            contacts.add(map);
            //记得要把cursor给close掉
            phoneCursor.close();
        }
        cursor.close();
        return contacts;
    }


}
